@@ -37,7 +37,8 @@ from rgi.geopackage.extensions.vector_tiles.vector_styles.styles_extension_const
 from rgi.geopackage.extensions.vector_tiles.vector_styles.stylesheets_entry import StyleSheetsEntry
 from rgi.geopackage.extensions.vector_tiles.vector_tiles_constants import GEOPACKAGE_VECTOR_LAYERS_TABLE_NAME
 from rgi.geopackage.utility.sql_column_query import SqlColumnQuery
-from rgi.geopackage.utility.sql_utility import table_exists, select_all_query, select_query, insert_or_update_row
+from rgi.geopackage.utility.sql_utility import table_exists, select_all_query, select_query, insert_or_update_row, \
+    validate_table_schema
 
 
 class GeoPackageStylesheetsTableAdapter(ExtensionEntry):
@@ -47,6 +48,8 @@ class GeoPackageStylesheetsTableAdapter(ExtensionEntry):
      https://portal.opengeospatial.org/wiki/pub/VectorTilesPilot/ConvertDocsOutputVTP/VTP/VTPExtension.pdf
     """
 
+    __stylesheets_column_names = ['id', 'styles_set', 'style', 'format', 'stylesheet', 'title', 'description']
+
     def __init__(self):
         super(GeoPackageStylesheetsTableAdapter, self).__init__(table_name=GEOPACKAGE_STYLESHEETS_TABLE_NAME,
                                                                 column_name=None,
@@ -54,6 +57,19 @@ class GeoPackageStylesheetsTableAdapter(ExtensionEntry):
                                                                 definition=STYLESHEETS_TILES_DEFINITION,
                                                                 scope=EXTENSION_READ_WRITE_SCOPE)
 
+    @staticmethod
+    def validate_stylesheets_table(cursor):
+        """
+        Validate the GeoPackage Stylesheets table to ensure the table exists with the expected schema. Raises an error
+        if the schema or table doesn't exist.
+
+        :param cursor: the cursor to the GeoPackage database's connection
+        :type cursor: Cursor
+        """
+        validate_table_schema(cursor=cursor,
+                              table_name=GEOPACKAGE_STYLESHEETS_TABLE_NAME,
+                              expected_columns=GeoPackageStylesheetsTableAdapter.__stylesheets_column_names)
+
     @staticmethod
     def create_stylesheets_table(cursor):
         """
@@ -90,8 +106,7 @@ class GeoPackageStylesheetsTableAdapter(ExtensionEntry):
         :return a list of Stylesheet entries that exist in the GeoPackage's gpkgext_stylesheets table
         :rtype: list of StyleSheetsEntry
         """
-        if not table_exists(cursor, GEOPACKAGE_STYLESHEETS_TABLE_NAME):
-            return []
+        GeoPackageStylesheetsTableAdapter.validate_stylesheets_table(cursor=cursor)
 
         # select all the rows
         rows = select_all_query(cursor=cursor,
@@ -120,12 +135,8 @@ class GeoPackageStylesheetsTableAdapter(ExtensionEntry):
         :return a list of Stylesheet entries that exist in the GeoPackage's gpkgext_stylesheets table
         :rtype: list of StyleSheetsEntry
         """
-        if not table_exists(cursor, GEOPACKAGE_STYLESHEETS_TABLE_NAME):
-            raise ValueError("The table {table} does not exist.".format(table=GEOPACKAGE_STYLESHEETS_TABLE_NAME))
-
-        if not GeoPackageVectorLayersTableAdapter.table_exists(cursor=cursor):
-            raise ValueError("The table '{table}' does not exist or does not have the correct columns."
-                             .format(table=GEOPACKAGE_VECTOR_LAYERS_TABLE_NAME))
+        GeoPackageStylesheetsTableAdapter.validate_stylesheets_table(cursor=cursor)
+        GeoPackageVectorLayersTableAdapter.validate_vector_layers_table(cursor=cursor)
 
         sql_query = """
                      SELECT * 
@@ -170,12 +181,8 @@ class GeoPackageStylesheetsTableAdapter(ExtensionEntry):
         :rtype: list of StyleSheetsEntry
         """
 
-        if not table_exists(cursor, GEOPACKAGE_STYLESHEETS_TABLE_NAME):
-            raise ValueError("The table {table} does not exist.".format(table=GEOPACKAGE_STYLESHEETS_TABLE_NAME))
-
-        if not GeoPackageVectorLayersTableAdapter.table_exists(cursor=cursor):
-            raise ValueError("The table '{table}' does not exist or does not have the correct columns."
-                             .format(table=GEOPACKAGE_VECTOR_LAYERS_TABLE_NAME))
+        GeoPackageStylesheetsTableAdapter.validate_stylesheets_table(cursor=cursor)
+        GeoPackageVectorLayersTableAdapter.validate_vector_layers_table(cursor=cursor)
 
         sql_query = """
                      SELECT * 
@@ -213,8 +220,7 @@ class GeoPackageStylesheetsTableAdapter(ExtensionEntry):
 
         :rtype: list of StyleSheetsEntry
         """
-        if not table_exists(cursor, GEOPACKAGE_STYLESHEETS_TABLE_NAME):
-            raise ValueError("The table {table} does not exist.".format(table=GEOPACKAGE_STYLESHEETS_TABLE_NAME))
+        GeoPackageStylesheetsTableAdapter.validate_stylesheets_table(cursor=cursor)
 
         rows = select_query(cursor=cursor,
                             table_name=GEOPACKAGE_STYLESHEETS_TABLE_NAME,
@@ -249,9 +255,12 @@ class GeoPackageStylesheetsTableAdapter(ExtensionEntry):
 
         :return Updated StyleSheetsEntry with the id value updated if needed
         """
-        if not table_exists(cursor, GEOPACKAGE_STYLESHEETS_TABLE_NAME):
+        if not table_exists(cursor=cursor,
+                            table_name=GEOPACKAGE_STYLESHEETS_TABLE_NAME):
             GeoPackageStylesheetsTableAdapter.create_stylesheets_table(cursor=cursor)
 
+        GeoPackageStylesheetsTableAdapter.validate_stylesheets_table(cursor=cursor)
+
         # TODO validate layer_id if not none? check to make sure it references a value in the gpkgext_vt_layers table
 
         # if user did not provide an id for the row to insert/update use the unique clause (styles_set, style, and
